@@ -187,6 +187,53 @@ def add_numbers(labels:list, style:str='per_element'):
 
     return labels_wn
 
+def count_n_atoms(form_str:str):
+    """
+    Count number of atoms in a chemical formula
+
+    Positional arguments:
+        form_str (str) : chemical formula string
+
+    Keyword arguments:
+        None
+
+    Returns:
+        n_atoms (int) : number of atoms in chemical formula
+    """
+
+    form_dict = formstr_to_formdict(form_str)
+
+    n_atoms = sum(form_dict.values())
+
+    return n_atoms
+
+def index_elements(labels:list):
+    """
+    Return dictionary of element (keys) and indices (values) from list of labels
+
+    Positional arguments:
+        labels (list) : atomic labels
+
+    Keyword arguments:
+        None
+
+    Returns:
+        ele_index (dict) : dictionary of element (keys) and indices (values)
+    """
+
+    labels_nn = remove_numbers(labels)
+
+    ele_index = {}
+
+    for it,lab in enumerate(labels_nn):
+        try:
+            ele_index[lab].append(it)
+        except KeyError:
+            ele_index[lab] = [it]
+
+    return ele_index
+
+
 def count_elements(labels:list):
     """
     Count number of each element in a list of elements
